==> magics++_4.1.2.orig.tar.xz: magics++-4.1.2/README.md <==

Magics README
=============

[![Linux & macOS: master](https://img.shields.io/travis/ecmwf/magics/master.svg?label=Linux-and-macOS-master)](https://travis-ci.org/ecmwf/magics/branches)
[![Linux & macOS: develop](https://img.shields.io/travis/ecmwf/magics/develop.svg?label=Linux-and-macOS-dev)](https://travis-ci.org/ecmwf/magics/branches)
[![Windows: master](https://img.shields.io/appveyor/ci/ecmwf/magics/master.svg?label=Windows-master)](https://ci.appveyor.com/project/ecmwf/magics/branch/master)
[![Windows: develop](https://img.shields.io/appveyor/ci/ecmwf/magics/develop.svg?label=Windows-dev)](https://ci.appveyor.com/project/ecmwf/magics/branch/develop)

Getting the source
------------------

The tarball of the source can be downloaded from 

     https://software.ecmwf.int/magics/Releases


Installation
------------

Please read the installation guide:

  https://software.ecmwf.int/magics/Installation+Guide


License
-------

Copyright 1996-2019 European Centre for Medium-Range Weather Forecasts (ECMWF).

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at: http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

==> magics++_4.2.6.orig.tar.xz: magics++-4.2.6/README.md <==

Magics README
=============

[![Linux & macOS: master](https://img.shields.io/travis/ecmwf/magics/master.svg?label=Linux-and-macOS-master)](https://travis-ci.org/ecmwf/magics/branches)
[![Linux & macOS: develop](https://img.shields.io/travis/ecmwf/magics/develop.svg?label=Linux-and-macOS-dev)](https://travis-ci.org/ecmwf/magics/branches)
[![Windows: master](https://img.shields.io/appveyor/ci/ecmwf/magics/master.svg?label=Windows-master)](https://ci.appveyor.com/project/ecmwf/magics/branch/master)
[![Windows: develop](https://img.shields.io/appveyor/ci/ecmwf/magics/develop.svg?label=Windows-dev)](https://ci.appveyor.com/project/ecmwf/magics/branch/develop)

Python Package: Pypi or conda
--------------

[![PyPI version](https://badge.fury.io/py/Magics.svg)](https://badge.fury.io/py/Magics)
[![Conda version](https://anaconda.org/conda-forge/magics/badges/version.svg)](https://anaconda.org/conda-forge/magics)
[![Conda download](https://anaconda.org/conda-forge/magics/badges/downloads.svg)](https://anaconda.org/conda-forge/magics)



Gallery of Notebooks
--------------------

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/ecmwf/notebook-examples.git/master)


Docker Image
------------

[![Docker Build Status](https://img.shields.io/docker/cloud/build/ecmwf/magics.svg)](https://hub.docker.com/r/ecmwf/magics)
[![Docker Pulls](https://img.shields.io/docker/pulls/ecmwf/magics)](https://hub.docker.com/r/ecmwf/magics)


Installation
------------

Please read the installation guide:

  https://software.ecmwf.int/magics/Installation+Guide


License
-------

Copyright 1996-2019 European Centre for Medium-Range Weather Forecasts (ECMWF).

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at: http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
